"""
Exports CATEGORY_MC table keyed by supporting unicode version level.

This code generated by python wcwidth project.
"""
# pylint: disable=duplicate-code
CATEGORY_MC = {
    '17.0.0': (
        # Source: DerivedGeneralCategory-17.0.0.txt
        # Date: 2025-07-24, 00:12:50 GMT
        #
        (0x00903, 0x00903,),  # Devanagari Sign Visarga
        (0x0093b, 0x0093b,),  # Devanagari Vowel Sign Ooe
        (0x0093e, 0x00940,),  # Devanagari Vowel Sign Aa..Devanagari Vowel Sign Ii
        (0x00949, 0x0094c,),  # Devanagari Vowel Sign Ca..Devanagari Vowel Sign Au
        (0x0094e, 0x0094f,),  # Devanagari Vowel Sign Pr..Devanagari Vowel Sign Aw
        (0x00982, 0x00983,),  # Bengali Sign Anusvara   ..Bengali Sign Visarga
        (0x009be, 0x009c0,),  # Bengali Vowel Sign Aa   ..Bengali Vowel Sign Ii
        (0x009c7, 0x009c8,),  # Bengali Vowel Sign E    ..Bengali Vowel Sign Ai
        (0x009cb, 0x009cc,),  # Bengali Vowel Sign O    ..Bengali Vowel Sign Au
        (0x009d7, 0x009d7,),  # Bengali Au Length Mark
        (0x00a03, 0x00a03,),  # Gurmukhi Sign Visarga
        (0x00a3e, 0x00a40,),  # Gurmukhi Vowel Sign Aa  ..Gurmukhi Vowel Sign Ii
        (0x00a83, 0x00a83,),  # Gujarati Sign Visarga
        (0x00abe, 0x00ac0,),  # Gujarati Vowel Sign Aa  ..Gujarati Vowel Sign Ii
        (0x00ac9, 0x00ac9,),  # Gujarati Vowel Sign Candra O
        (0x00acb, 0x00acc,),  # Gujarati Vowel Sign O   ..Gujarati Vowel Sign Au
        (0x00b02, 0x00b03,),  # Oriya Sign Anusvara     ..Oriya Sign Visarga
        (0x00b3e, 0x00b3e,),  # Oriya Vowel Sign Aa
        (0x00b40, 0x00b40,),  # Oriya Vowel Sign Ii
        (0x00b47, 0x00b48,),  # Oriya Vowel Sign E      ..Oriya Vowel Sign Ai
        (0x00b4b, 0x00b4c,),  # Oriya Vowel Sign O      ..Oriya Vowel Sign Au
        (0x00b57, 0x00b57,),  # Oriya Au Length Mark
        (0x00bbe, 0x00bbf,),  # Tamil Vowel Sign Aa     ..Tamil Vowel Sign I
        (0x00bc1, 0x00bc2,),  # Tamil Vowel Sign U      ..Tamil Vowel Sign Uu
        (0x00bc6, 0x00bc8,),  # Tamil Vowel Sign E      ..Tamil Vowel Sign Ai
        (0x00bca, 0x00bcc,),  # Tamil Vowel Sign O      ..Tamil Vowel Sign Au
        (0x00bd7, 0x00bd7,),  # Tamil Au Length Mark
        (0x00c01, 0x00c03,),  # Telugu Sign Candrabindu ..Telugu Sign Visarga
        (0x00c41, 0x00c44,),  # Telugu Vowel Sign U     ..Telugu Vowel Sign Vocali
        (0x00c82, 0x00c83,),  # Kannada Sign Anusvara   ..Kannada Sign Visarga
        (0x00cbe, 0x00cbe,),  # Kannada Vowel Sign Aa
        (0x00cc0, 0x00cc4,),  # Kannada Vowel Sign Ii   ..Kannada Vowel Sign Vocal
        (0x00cc7, 0x00cc8,),  # Kannada Vowel Sign Ee   ..Kannada Vowel Sign Ai
        (0x00cca, 0x00ccb,),  # Kannada Vowel Sign O    ..Kannada Vowel Sign Oo
        (0x00cd5, 0x00cd6,),  # Kannada Length Mark     ..Kannada Ai Length Mark
        (0x00cf3, 0x00cf3,),  # Kannada Sign Combining Anusvara Above Right
        (0x00d02, 0x00d03,),  # Malayalam Sign Anusvara ..Malayalam Sign Visarga
        (0x00d3e, 0x00d40,),  # Malayalam Vowel Sign Aa ..Malayalam Vowel Sign Ii
        (0x00d46, 0x00d48,),  # Malayalam Vowel Sign E  ..Malayalam Vowel Sign Ai
        (0x00d4a, 0x00d4c,),  # Malayalam Vowel Sign O  ..Malayalam Vowel Sign Au
        (0x00d57, 0x00d57,),  # Malayalam Au Length Mark
        (0x00d82, 0x00d83,),  # Sinhala Sign Anusvaraya ..Sinhala Sign Visargaya
        (0x00dcf, 0x00dd1,),  # Sinhala Vowel Sign Aela-..Sinhala Vowel Sign Diga
        (0x00dd8, 0x00ddf,),  # Sinhala Vowel Sign Gaett..Sinhala Vowel Sign Gayan
        (0x00df2, 0x00df3,),  # Sinhala Vowel Sign Diga ..Sinhala Vowel Sign Diga
        (0x00f3e, 0x00f3f,),  # Tibetan Sign Yar Tshes  ..Tibetan Sign Mar Tshes
        (0x00f7f, 0x00f7f,),  # Tibetan Sign Rnam Bcad
        (0x0102b, 0x0102c,),  # Myanmar Vowel Sign Tall ..Myanmar Vowel Sign Aa
        (0x01031, 0x01031,),  # Myanmar Vowel Sign E
        (0x01038, 0x01038,),  # Myanmar Sign Visarga
        (0x0103b, 0x0103c,),  # Myanmar Consonant Sign M..Myanmar Consonant Sign M
        (0x01056, 0x01057,),  # Myanmar Vowel Sign Vocal..Myanmar Vowel Sign Vocal
        (0x01062, 0x01064,),  # Myanmar Vowel Sign Sgaw ..Myanmar Tone Mark Sgaw K
        (0x01067, 0x0106d,),  # Myanmar Vowel Sign Weste..Myanmar Sign Western Pwo
        (0x01083, 0x01084,),  # Myanmar Vowel Sign Shan ..Myanmar Vowel Sign Shan
        (0x01087, 0x0108c,),  # Myanmar Sign Shan Tone-2..Myanmar Sign Shan Counci
        (0x0108f, 0x0108f,),  # Myanmar Sign Rumai Palaung Tone-5
        (0x0109a, 0x0109c,),  # Myanmar Sign Khamti Tone..Myanmar Vowel Sign Aiton
        (0x01715, 0x01715,),  # Tagalog Sign Pamudpod
        (0x01734, 0x01734,),  # Hanunoo Sign Pamudpod
        (0x017b6, 0x017b6,),  # Khmer Vowel Sign Aa
        (0x017be, 0x017c5,),  # Khmer Vowel Sign Oe     ..Khmer Vowel Sign Au
        (0x017c7, 0x017c8,),  # Khmer Sign Reahmuk      ..Khmer Sign Yuukaleapintu
        (0x01923, 0x01926,),  # Limbu Vowel Sign Ee     ..Limbu Vowel Sign Au
        (0x01929, 0x0192b,),  # Limbu Subjoined Letter Y..Limbu Subjoined Letter W
        (0x01930, 0x01931,),  # Limbu Small Letter Ka   ..Limbu Small Letter Nga
        (0x01933, 0x01938,),  # Limbu Small Letter Ta   ..Limbu Small Letter La
        (0x01a19, 0x01a1a,),  # Buginese Vowel Sign E   ..Buginese Vowel Sign O
        (0x01a55, 0x01a55,),  # Tai Tham Consonant Sign Medial Ra
        (0x01a57, 0x01a57,),  # Tai Tham Consonant Sign La Tang Lai
        (0x01a61, 0x01a61,),  # Tai Tham Vowel Sign A
        (0x01a63, 0x01a64,),  # Tai Tham Vowel Sign Aa  ..Tai Tham Vowel Sign Tall
        (0x01a6d, 0x01a72,),  # Tai Tham Vowel Sign Oy  ..Tai Tham Vowel Sign Tham
        (0x01b04, 0x01b04,),  # Balinese Sign Bisah
        (0x01b35, 0x01b35,),  # Balinese Vowel Sign Tedung
        (0x01b3b, 0x01b3b,),  # Balinese Vowel Sign Ra Repa Tedung
        (0x01b3d, 0x01b41,),  # Balinese Vowel Sign La L..Balinese Vowel Sign Tali
        (0x01b43, 0x01b44,),  # Balinese Vowel Sign Pepe..Balinese Adeg Adeg
        (0x01b82, 0x01b82,),  # Sundanese Sign Pangwisad
        (0x01ba1, 0x01ba1,),  # Sundanese Consonant Sign Pamingkal
        (0x01ba6, 0x01ba7,),  # Sundanese Vowel Sign Pan..Sundanese Vowel Sign Pan
        (0x01baa, 0x01baa,),  # Sundanese Sign Pamaaeh
        (0x01be7, 0x01be7,),  # Batak Vowel Sign E
        (0x01bea, 0x01bec,),  # Batak Vowel Sign I      ..Batak Vowel Sign O
        (0x01bee, 0x01bee,),  # Batak Vowel Sign U
        (0x01bf2, 0x01bf3,),  # Batak Pangolat          ..Batak Panongonan
        (0x01c24, 0x01c2b,),  # Lepcha Subjoined Letter ..Lepcha Vowel Sign Uu
        (0x01c34, 0x01c35,),  # Lepcha Consonant Sign Ny..Lepcha Consonant Sign Ka
        (0x01ce1, 0x01ce1,),  # Vedic Tone Atharvavedic Independent Svarita
        (0x01cf7, 0x01cf7,),  # Vedic Sign Atikrama
        (0x0302e, 0x0302f,),  # Hangul Single Dot Tone M..Hangul Double Dot Tone M
        (0x0a823, 0x0a824,),  # Syloti Nagri Vowel Sign ..Syloti Nagri Vowel Sign
        (0x0a827, 0x0a827,),  # Syloti Nagri Vowel Sign Oo
        (0x0a880, 0x0a881,),  # Saurashtra Sign Anusvara..Saurashtra Sign Visarga
        (0x0a8b4, 0x0a8c3,),  # Saurashtra Consonant Sig..Saurashtra Vowel Sign Au
        (0x0a952, 0x0a953,),  # Rejang Consonant Sign H ..Rejang Virama
        (0x0a983, 0x0a983,),  # Javanese Sign Wignyan
        (0x0a9b4, 0x0a9b5,),  # Javanese Vowel Sign Taru..Javanese Vowel Sign Tolo
        (0x0a9ba, 0x0a9bb,),  # Javanese Vowel Sign Tali..Javanese Vowel Sign Dirg
        (0x0a9be, 0x0a9c0,),  # Javanese Consonant Sign ..Javanese Pangkon
        (0x0aa2f, 0x0aa30,),  # Cham Vowel Sign O       ..Cham Vowel Sign Ai
        (0x0aa33, 0x0aa34,),  # Cham Consonant Sign Ya  ..Cham Consonant Sign Ra
        (0x0aa4d, 0x0aa4d,),  # Cham Consonant Sign Final H
        (0x0aa7b, 0x0aa7b,),  # Myanmar Sign Pao Karen Tone
        (0x0aa7d, 0x0aa7d,),  # Myanmar Sign Tai Laing Tone-5
        (0x0aaeb, 0x0aaeb,),  # Meetei Mayek Vowel Sign Ii
        (0x0aaee, 0x0aaef,),  # Meetei Mayek Vowel Sign ..Meetei Mayek Vowel Sign
        (0x0aaf5, 0x0aaf5,),  # Meetei Mayek Vowel Sign Visarga
        (0x0abe3, 0x0abe4,),  # Meetei Mayek Vowel Sign ..Meetei Mayek Vowel Sign
        (0x0abe6, 0x0abe7,),  # Meetei Mayek Vowel Sign ..Meetei Mayek Vowel Sign
        (0x0abe9, 0x0abea,),  # Meetei Mayek Vowel Sign ..Meetei Mayek Vowel Sign
        (0x0abec, 0x0abec,),  # Meetei Mayek Lum Iyek
        (0x11000, 0x11000,),  # Brahmi Sign Candrabindu
        (0x11002, 0x11002,),  # Brahmi Sign Visarga
        (0x11082, 0x11082,),  # Kaithi Sign Visarga
        (0x110b0, 0x110b2,),  # Kaithi Vowel Sign Aa    ..Kaithi Vowel Sign Ii
        (0x110b7, 0x110b8,),  # Kaithi Vowel Sign O     ..Kaithi Vowel Sign Au
        (0x1112c, 0x1112c,),  # Chakma Vowel Sign E
        (0x11145, 0x11146,),  # Chakma Vowel Sign Aa    ..Chakma Vowel Sign Ei
        (0x11182, 0x11182,),  # Sharada Sign Visarga
        (0x111b3, 0x111b5,),  # Sharada Vowel Sign Aa   ..Sharada Vowel Sign Ii
        (0x111bf, 0x111c0,),  # Sharada Vowel Sign Au   ..Sharada Sign Virama
        (0x111ce, 0x111ce,),  # Sharada Vowel Sign Prishthamatra E
        (0x1122c, 0x1122e,),  # Khojki Vowel Sign Aa    ..Khojki Vowel Sign Ii
        (0x11232, 0x11233,),  # Khojki Vowel Sign O     ..Khojki Vowel Sign Au
        (0x11235, 0x11235,),  # Khojki Sign Virama
        (0x112e0, 0x112e2,),  # Khudawadi Vowel Sign Aa ..Khudawadi Vowel Sign Ii
        (0x11302, 0x11303,),  # Grantha Sign Anusvara   ..Grantha Sign Visarga
        (0x1133e, 0x1133f,),  # Grantha Vowel Sign Aa   ..Grantha Vowel Sign I
        (0x11341, 0x11344,),  # Grantha Vowel Sign U    ..Grantha Vowel Sign Vocal
        (0x11347, 0x11348,),  # Grantha Vowel Sign Ee   ..Grantha Vowel Sign Ai
        (0x1134b, 0x1134d,),  # Grantha Vowel Sign Oo   ..Grantha Sign Virama
        (0x11357, 0x11357,),  # Grantha Au Length Mark
        (0x11362, 0x11363,),  # Grantha Vowel Sign Vocal..Grantha Vowel Sign Vocal
        (0x113b8, 0x113ba,),  # Tulu-tigalari Vowel Sign..Tulu-tigalari Vowel Sign
        (0x113c2, 0x113c2,),  # Tulu-tigalari Vowel Sign Ee
        (0x113c5, 0x113c5,),  # Tulu-tigalari Vowel Sign Ai
        (0x113c7, 0x113ca,),  # Tulu-tigalari Vowel Sign..Tulu-tigalari Sign Candr
        (0x113cc, 0x113cd,),  # Tulu-tigalari Sign Anusv..Tulu-tigalari Sign Visar
        (0x113cf, 0x113cf,),  # Tulu-tigalari Sign Looped Virama
        (0x11435, 0x11437,),  # Newa Vowel Sign Aa      ..Newa Vowel Sign Ii
        (0x11440, 0x11441,),  # Newa Vowel Sign O       ..Newa Vowel Sign Au
        (0x11445, 0x11445,),  # Newa Sign Visarga
        (0x114b0, 0x114b2,),  # Tirhuta Vowel Sign Aa   ..Tirhuta Vowel Sign Ii
        (0x114b9, 0x114b9,),  # Tirhuta Vowel Sign E
        (0x114bb, 0x114be,),  # Tirhuta Vowel Sign Ai   ..Tirhuta Vowel Sign Au
        (0x114c1, 0x114c1,),  # Tirhuta Sign Visarga
        (0x115af, 0x115b1,),  # Siddham Vowel Sign Aa   ..Siddham Vowel Sign Ii
        (0x115b8, 0x115bb,),  # Siddham Vowel Sign E    ..Siddham Vowel Sign Au
        (0x115be, 0x115be,),  # Siddham Sign Visarga
        (0x11630, 0x11632,),  # Modi Vowel Sign Aa      ..Modi Vowel Sign Ii
        (0x1163b, 0x1163c,),  # Modi Vowel Sign O       ..Modi Vowel Sign Au
        (0x1163e, 0x1163e,),  # Modi Sign Visarga
        (0x116ac, 0x116ac,),  # Takri Sign Visarga
        (0x116ae, 0x116af,),  # Takri Vowel Sign I      ..Takri Vowel Sign Ii
        (0x116b6, 0x116b6,),  # Takri Sign Virama
        (0x1171e, 0x1171e,),  # Ahom Consonant Sign Medial Ra
        (0x11720, 0x11721,),  # Ahom Vowel Sign A       ..Ahom Vowel Sign Aa
        (0x11726, 0x11726,),  # Ahom Vowel Sign E
        (0x1182c, 0x1182e,),  # Dogra Vowel Sign Aa     ..Dogra Vowel Sign Ii
        (0x11838, 0x11838,),  # Dogra Sign Visarga
        (0x11930, 0x11935,),  # Dives Akuru Vowel Sign A..Dives Akuru Vowel Sign E
        (0x11937, 0x11938,),  # Dives Akuru Vowel Sign A..Dives Akuru Vowel Sign O
        (0x1193d, 0x1193d,),  # Dives Akuru Sign Halanta
        (0x11940, 0x11940,),  # Dives Akuru Medial Ya
        (0x11942, 0x11942,),  # Dives Akuru Medial Ra
        (0x119d1, 0x119d3,),  # Nandinagari Vowel Sign A..Nandinagari Vowel Sign I
        (0x119dc, 0x119df,),  # Nandinagari Vowel Sign O..Nandinagari Sign Visarga
        (0x119e4, 0x119e4,),  # Nandinagari Vowel Sign Prishthamatra E
        (0x11a39, 0x11a39,),  # Zanabazar Square Sign Visarga
        (0x11a57, 0x11a58,),  # Soyombo Vowel Sign Ai   ..Soyombo Vowel Sign Au
        (0x11a97, 0x11a97,),  # Soyombo Sign Visarga
        (0x11b61, 0x11b61,),  # Sharada Vowel Sign Ooe
        (0x11b65, 0x11b65,),  # Sharada Vowel Sign Short O
        (0x11b67, 0x11b67,),  # Sharada Vowel Sign Candra O
        (0x11c2f, 0x11c2f,),  # Bhaiksuki Vowel Sign Aa
        (0x11c3e, 0x11c3e,),  # Bhaiksuki Sign Visarga
        (0x11ca9, 0x11ca9,),  # Marchen Subjoined Letter Ya
        (0x11cb1, 0x11cb1,),  # Marchen Vowel Sign I
        (0x11cb4, 0x11cb4,),  # Marchen Vowel Sign O
        (0x11d8a, 0x11d8e,),  # Gunjala Gondi Vowel Sign..Gunjala Gondi Vowel Sign
        (0x11d93, 0x11d94,),  # Gunjala Gondi Vowel Sign..Gunjala Gondi Vowel Sign
        (0x11d96, 0x11d96,),  # Gunjala Gondi Sign Visarga
        (0x11ef5, 0x11ef6,),  # Makasar Vowel Sign E    ..Makasar Vowel Sign O
        (0x11f03, 0x11f03,),  # Kawi Sign Visarga
        (0x11f34, 0x11f35,),  # Kawi Vowel Sign Aa      ..Kawi Vowel Sign Alternat
        (0x11f3e, 0x11f3f,),  # Kawi Vowel Sign E       ..Kawi Vowel Sign Ai
        (0x11f41, 0x11f41,),  # Kawi Sign Killer
        (0x1612a, 0x1612c,),  # Gurung Khema Consonant S..Gurung Khema Consonant S
        (0x16f51, 0x16f87,),  # Miao Sign Aspiration    ..Miao Vowel Sign Ui
        (0x16ff0, 0x16ff1,),  # Vietnamese Alternate Rea..Vietnamese Alternate Rea
        (0x1d165, 0x1d166,),  # Musical Symbol Combining..Musical Symbol Combining
        (0x1d16d, 0x1d172,),  # Musical Symbol Combining..Musical Symbol Combining
    ),
}
